hidePassword property
Whether to hide the passcode text in the in-meeting UI.
Android only (MeetingViewsOptions.NO_TEXT_PASSWORD) — there is no iOS
equivalent. Ignored on iOS.
Implementation
final bool hidePassword;
Whether to hide the passcode text in the in-meeting UI.
Android only (MeetingViewsOptions.NO_TEXT_PASSWORD) — there is no iOS
equivalent. Ignored on iOS.
final bool hidePassword;