BreakoutRoom class
Describes a single Zoom breakout room.
Constructors
-
BreakoutRoom({required String boId, required String name, List<
String> userIds = const []}) - Creates a breakout room description.
- BreakoutRoom.fromMap(Map map)
-
Builds a BreakoutRoom from a platform-channel
map.factory
Properties
- boId → String
-
The unique identifier of the breakout room.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
The display name of the breakout room.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
userIds
→ List<
String> -
The IDs of the participants assigned to this room.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited