ZoomMeetingStatus enum
The high-level connection state of a Zoom meeting.
Values
- idle → const ZoomMeetingStatus
-
No meeting is active.
- connecting → const ZoomMeetingStatus
-
The SDK is establishing a connection to the meeting.
- inMeeting → const ZoomMeetingStatus
-
The local user is connected and in the meeting.
- waitingForHost → const ZoomMeetingStatus
-
The local user is in the waiting room until the host admits them.
- disconnecting → const ZoomMeetingStatus
-
The SDK is in the process of leaving the meeting.
- ended → const ZoomMeetingStatus
-
The meeting has ended.
- failed → const ZoomMeetingStatus
-
The connection attempt failed.
- unknown → const ZoomMeetingStatus
-
The status could not be determined.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ZoomMeetingStatus> - A constant List of the values in this enum, in order of their declaration.