ZoomOptions class
Configuration used to initialize the Zoom SDK.
Constructors
- ZoomOptions({required String jwtToken, String domain = 'zoom.us', bool enableLog = true})
-
Creates the options used by
FlutterZoomSdkAdvanced.initZoom.
Properties
- domain → String
-
The Zoom web domain to connect to. Defaults to
zoom.us.final - enableLog → bool
-
Whether the native SDK should emit verbose logs.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- jwtToken → String
-
The JWT token used to authenticate the SDK with Zoom.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> - Serializes these options into a map for the platform channel.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited